Crate trailgen_gui

Crate trailgen_gui 

Structs

SavedTrailListing

Enums

ProjectIntent

Functions

export_saved_gpx
Export one durable Library trail, selected by exact identity or unique name.
run
Resume or explicitly open a trailgen project in the native workbench.
saved_trails
Enumerate the only trails eligible for product export: durable Library entries.